DeviceBus

Struct DeviceBus 

pub struct DeviceBus { /* private fields */ }
A bus interface to the HLApi

Implementations

Source

impl DeviceBus

pub fn new(path: impl AsRef<Path>) -> Result<DeviceBus>

pub fn call<T: Serialize, R: Deserialize>( &mut self, msg: &Call<T>, ) -> Result<Response<R>>

Calls a HLApi method and gets its response.

pub fn call_preserialized<R: Deserialize>( &mut self, msg: &[u8], ) -> Result<Response<R>>

Calls a HLApi method and gets its response. Uses a pre-serialized string to help with optimizations for zero-argument functions.

pub fn wrap<T: IdentifiedDevice>(&mut self) -> Result<Option<T>>

Utility method to create a wrapper for a device of a certain type.

pub fn find(&mut self, kind: &str) -> Result<Option<String>>

Utility method to find a device id for a certain device type.