pub struct InventoryOperationsModule(pub String);Expand description
A device capable of manipulating inventories in the world
Tuple Fields
0: StringTrait Implementations
Sourceimpl InventoryOperationsInterface for InventoryOperationsModule
impl InventoryOperationsInterface for InventoryOperationsModule
Sourcefn move_stack(
&self,
bus: &mut DeviceBus,
from: i32,
into: i32,
count: i32,
) -> Result<Option<()>>
fn move_stack( &self, bus: &mut DeviceBus, from: i32, into: i32, count: i32, ) -> Result<Option<()>>
OC2 Docs:
tries to move the specified number of items from one robot inventory slot to another.
Sourcefn drop(&self, bus: &mut DeviceBus, count: i32, side: &str) -> Result<i32>
fn drop(&self, bus: &mut DeviceBus, count: i32, side: &str) -> Result<i32>
OC2 Docs:
tries to drop items from the specified slot in the specified direction. It will drop items either into an inventory, or the world if no inventory is present.
Returns the number of items dropped.
Sourcefn drop_into(
&self,
bus: &mut DeviceBus,
into: i32,
count: i32,
side: &str,
) -> Result<i32>
fn drop_into( &self, bus: &mut DeviceBus, into: i32, count: i32, side: &str, ) -> Result<i32>
OC2 Docs:
tries to drop items from the specified slot into the specified slot of an inventory in the specified direction. It will only drop items into an inventory.
Returns the number of items dropped.
Sourcefn take(&self, bus: &mut DeviceBus, count: i32, side: &str) -> Result<i32>
fn take(&self, bus: &mut DeviceBus, count: i32, side: &str) -> Result<i32>
OC2 Docs:
tries to take the specified number of items from the specified direction. It will take items from either an inventory, or the world if no inventory is present.
Returns the number of items taken.
Sourcefn take_from(
&self,
bus: &mut DeviceBus,
from: i32,
count: i32,
side: &str,
) -> Result<i32>
fn take_from( &self, bus: &mut DeviceBus, from: i32, count: i32, side: &str, ) -> Result<i32>
OC2 Docs:
tries to take the specified number of items from the specified slot from an inventory in the specified direction. It will only take items from an inventory.
Returns the number of items taken.